@@ -19,8 +19,9 @@ import re
 import subprocess
 import tempfile
 import sys
+from ConfigParser import ConfigParser
 
-import base
+from iw.releaser import base
 
 re_version = re.compile(r"""^version\s*=\s*(?:"|')(.*?)(?:"|')""",
                         re.MULTILINE|re.DOTALL)  
@@ -143,6 +144,39 @@ def _run_setup(*args):
 def pypi_upload():
     """upload into pypi"""
     _checkout_tag()
-    # let's upload
-    _run_setup('mregister', 'sdist', 'bdist_egg', 'mupload')
+    # let's upload on selected servers
+    if os.environ.has_key('HOME'): 
+        rc = os.path.join(os.environ['HOME'], '.pypirc')
+        if not os.path.exists(rc):
+            return 
+        config = ConfigParser()
+        config.read(rc)
+        sections = config.sections()
+
+        if 'distutils' in sections:
+            index_servers = config.get('distutils', 'index-servers')
+            _servers = [server.strip() for server in 
+                        index_servers.split('\n')
+                        if server.strip() != '']
+            for server in _servers:
+                if config.has_option(server, 'repository'):
+                    repository = config.get(server, 'repository')
+                else:
+                    repository = 'http://pypi.python.org/pypi'
+                _pypi_upload(repository)
+
+        elif 'server-login' in sections:
+            if config.has_option(server, 'repository'):
+                repository = config.get(server, 'repository')
+            else:
+                repository = 'http://pypi.python.org/pypi' 
+            _pypi_upload(repository)     
+        
+def _pypi_upload(repository):
+    res = raw_input('Do you want to upload to %s ? (Y/n):' % repository)
+
+    res = res.lower().strip()
+    if res == 'y':
+        _run_setup('mregister', 'sdist', 'bdist_egg', 'mupload', '-r',
+                   repository)
 
